Plugins/PluginSyntaxChecker.py

changeset 830
6caa4436dee2
parent 802
e8882d16384c
child 945
8cd4d08fa9f6
child 955
377efd9104a7
--- a/Plugins/PluginSyntaxChecker.py	Sat Jan 08 20:37:14 2011 +0100
+++ b/Plugins/PluginSyntaxChecker.py	Sat Jan 08 20:39:23 2011 +0100
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the Tabnanny plugin.
+Module implementing the Syntax Checker plugin.
 """
 
 import os
@@ -171,7 +171,7 @@
     
     def __projectSyntaxCheck(self):
         """
         Public slot used to check the project files for bad indentations.
         """
         project = e5App().getObject("Project")
         project.saveAllScripts()
@@ -171,7 +171,7 @@
     def __projectSyntaxCheck(self):
         """
-        Public slot used to check the project files for bad indentations.
+        Public slot used to check the project files for syntax errors.
         """
         project = e5App().getObject("Project")

eric ide

mercurial